@@ -329,19 +329,20 @@ def list_running_jobs(team_only: bool = False):
     load_kube_config()
     username = os.environ.get("JUPYTERHUB_USER", os.environ.get("USERNAME"))
     api_instance = BatchV1Api()
-    field_selector = "status.successful!=1"
+    # field_selector = "status.successful!=1"
     if team_only:
         operand = "!="
     else:
         operand = "="
 
     label_selector = f"app=orbit-runner,username{operand}{username}"
+    _logger.info("using job selector %s", label_selector)
     try:
         api_response = api_instance.list_namespaced_job(
             namespace=team_name,
             _preload_content=False,
             label_selector=label_selector,
-            field_selector=field_selector,
+            # field_selector=field_selector,
             watch=False,
         )
         res = json.loads(api_response.data)
@@ -552,7 +553,7 @@ def _create_eks_job_spec(taskConfiguration: dict, labels: Dict[str, str], team_c
 def resolve_image(__CURRENT_TEAM_MANIFEST__, profile):
     if not profile or "kubespawner_override" not in profile or "image" not in profile["kubespawner_override"]:
         repository = __CURRENT_TEAM_MANIFEST__["FinalImageAddress"]
-        image = f"{repository}:latest"
+        image = f"{repository}"
     else:
         image = profile["kubespawner_override"]["image"]
     return image
@@ -862,8 +863,8 @@ def wait_for_tasks_to_complete(
     team_name = props["AWS_ORBIT_TEAM_SPACE"]
 
     incomplete_tasks = []
-    _logger.info("Waiting for %s tasks %s", len(tasks), tasks)
-
+    _logger.info("Waiting2 for %s tasks %s", len(tasks), tasks)
+    load_kube_config()
     while True:
         for task in tasks:
             _logger.debug("Checking execution state of: %s", task)
@@ -914,6 +915,7 @@ def wait_for_tasks_to_complete(
         else:
             _logger.info("waiting for %s", tasks)
             time.sleep(delay)
+            load_kube_config()
 
 
 def tail_logs(team_name, tasks) -> None:
